@@ -2,7 +2,7 @@ import logging
 import re
 from collections import Iterable
 from datetime import datetime
-from typing import List
+from typing import List, Union
 
 from google.api_core.exceptions import GoogleAPIError, NotFound, Conflict
 from google.cloud import bigquery
@@ -11,6 +11,7 @@ from google.cloud.bigquery import QueryJobConfig, QueryJob, TableReference, Data
 from google.cloud.bigquery.schema import _parse_schema_resource, _build_schema_resource
 
 from bigquery.ems_api_error import EmsApiError
+from bigquery.job.config.ems_extract_job_config import EmsExtractJobConfig, Compression, DestinationFormat
 from bigquery.job.config.ems_job_config import EmsJobPriority, EmsCreateDisposition, EmsWriteDisposition
 from bigquery.job.config.ems_load_job_config import EmsLoadJobConfig
 from bigquery.job.config.ems_query_job_config import EmsQueryJobConfig
@@ -68,7 +69,7 @@ class EmsBigqueryClient:
         except NotFound:
             return False
 
-    def get_job_list(self, min_creation_time: datetime = None, max_creation_time: datetime = None, max_result: int = 20) -> Iterable:
+    def get_job_list(self, min_creation_time: datetime = None, max_creation_time: datetime = None, max_result: int = 20, all_users: bool = True) -> Iterable:
         """
         Args:
             min_creation_time (datetime.datetime, optional):
@@ -79,10 +80,12 @@ class EmsBigqueryClient:
                 If the datetime has no time zone assumes UTC time.
             max_result (int, optional):
                 Maximum number of jobs to return.
+            all_users (bool):
+                If true, retrieves jobs submitted by all users
         Yields:
             EmsQueryJob: the next job
         """
-        for job in self.__bigquery_client.list_jobs(all_users=True,
+        for job in self.__bigquery_client.list_jobs(all_users=all_users,
                                                     max_results=max_result,
                                                     min_creation_time=min_creation_time,
                                                     max_creation_time=max_creation_time):
@@ -131,11 +134,16 @@ class EmsBigqueryClient:
         elif isinstance(job, ExtractJob):
             table = f'{job.source.project}.{job.source.dataset_id}.{job.source.table_id}'
             destination_uris = job.destination_uris
+            job_config = EmsExtractJobConfig(compression=Compression(job.compression),
+                                             destination_format=DestinationFormat(job.destination_format),
+                                             field_delimiter=job.field_delimiter,
+                                             print_header=job.print_header)
             return EmsExtractJob(job_id=job.job_id,
-                                    table=table,
-                                    destination_uris=destination_uris,
-                                    state=EmsJobState(job.state),
-                                    error_result=job.error_result)
+                                 table=table,
+                                 destination_uris=destination_uris,
+                                 job_config=job_config,
+                                 state=EmsJobState(job.state),
+                                 error_result=job.error_result)
         else:
             LOGGER.error(f"Unexpected job type for :{job}")
             LOGGER.error(f"Job type class: {job.__class__}")
@@ -153,17 +161,23 @@ class EmsBigqueryClient:
             return None
         return EmsWriteDisposition(disposition)
 
-    def get_jobs_with_prefix(self, job_prefix: str, min_creation_time: datetime, max_creation_time: datetime = None, max_result: int = 20) -> list:
-        jobs = self.get_job_list(min_creation_time, max_creation_time, max_result)
+    def get_jobs_with_prefix(self, job_prefix: str, min_creation_time: datetime, max_creation_time: datetime = None, max_result: int = 20, all_users: bool = True) -> list:
+        jobs = self.get_job_list(min_creation_time, max_creation_time, max_result, all_users=all_users)
         matched_jobs = filter(lambda x: job_prefix in x.job_id, jobs)
         return list(matched_jobs)
 
-    def relaunch_failed_jobs(self, job_prefix: str, min_creation_time: datetime, max_creation_time: datetime = None, max_attempts: int = 3,  max_result: int = None) -> list:
-        def launch(job: EmsQueryJob) -> str:
+    def relaunch_failed_jobs(self, job_prefix: str, min_creation_time: datetime, max_creation_time: datetime = None, max_attempts: int = 3,  max_result: int = None, all_users: bool = True) -> list:
+        def launch(job: Union[EmsQueryJob, EmsExtractJob]) -> str:
             prefix_with_retry = self.__decorate_id_with_retry(job.job_id, job_prefix, max_attempts)
-            return self.run_async_query(job.query, prefix_with_retry, job.query_config)
 
-        jobs = self.get_jobs_with_prefix(job_prefix, min_creation_time, max_creation_time, max_result)
+            if isinstance(job, EmsQueryJob):
+                return self.run_async_query(job.query, prefix_with_retry, job.query_config)
+            elif isinstance(job, EmsExtractJob):
+                return self.run_async_extract_job(prefix_with_retry, job.table, job.destination_uris, job.job_config)
+            else:
+                LOGGER.error(f"Unsupported job: {job}")
+
+        jobs = self.get_jobs_with_prefix(job_prefix, min_creation_time, max_creation_time, max_result, all_users=all_users)
         failed_jobs = [x for x in jobs if x.is_failed]
         return [launch(job) for job in failed_jobs]
 
@@ -187,10 +201,9 @@ class EmsBigqueryClient:
                                                           job_config=self.__create_load_job_config(config)).job_id
 
     def run_async_extract_job(self, job_id_prefix: str, table: str, destination_uris: List[str],
-                              print_header: bool = False) -> str:
+                              job_config: EmsExtractJobConfig) -> str:
 
-        extract_job_config = ExtractJobConfig()
-        extract_job_config.print_header = print_header
+        extract_job_config = self.__create_extract_job_config(job_config)
 
         return self.__bigquery_client.extract_table(source=TableReference.from_string(table_id=table),
                                                     destination_uris=destination_uris,
@@ -248,6 +261,15 @@ class EmsBigqueryClient:
         config.skip_leading_rows = ems_load_job_config.skip_leading_rows
         return config
 
+    def __create_extract_job_config(self, ems_job_config: EmsExtractJobConfig) -> ExtractJobConfig:
+        config = ExtractJobConfig()
+
+        config.compression = ems_job_config.compression.value
+        config.destination_format = ems_job_config.destination_format.value
+        config.field_delimiter = ems_job_config.field_delimiter
+        config.print_header = ems_job_config.print_header
+        return config
+
     def __create_job_config(self, ems_query_job_config: EmsQueryJobConfig) -> QueryJobConfig:
         job_config = QueryJobConfig()
         job_config.priority = ems_query_job_config.priority.value
