@@ -12,6 +12,7 @@ from tenacity import retry, stop_after_delay, retry_if_result
 
 from bigquery.ems_api_error import EmsApiError
 from bigquery.ems_bigquery_client import EmsBigqueryClient
+from bigquery.job.config.ems_extract_job_config import EmsExtractJobConfig, Compression, DestinationFormat
 from bigquery.job.config.ems_job_config import EmsWriteDisposition
 from bigquery.job.config.ems_load_job_config import EmsLoadJobConfig
 from bigquery.job.config.ems_query_job_config import EmsQueryJobConfig
@@ -31,6 +32,7 @@ class ItEmsBigqueryClient(TestCase):
     INSERT_TEMPLATE = "INSERT INTO `{}` (int_data, str_data) VALUES (1, 'hello')"
     SELECT_TEMPLATE = "SELECT * FROM `{}`"
     DUMMY_SELECT_TO_TABLE = "SELECT 1 AS int_data, 'hello' AS str_data"
+    TEST_BUCKET_NAME = GCP_PROJECT_ID + "-gcp-toolkit-it"
 
     @classmethod
     def setUpClass(cls):
@@ -47,10 +49,15 @@ class ItEmsBigqueryClient(TestCase):
 
     def setUp(self):
         table_name = "test_table_" + str(int(datetime.datetime.utcnow().timestamp() * 1000))
-        self.test_table  = self.__create_test_table(table_name, self.DATASET.reference)
+        self.test_table = self.__create_test_table(table_name, self.DATASET.reference)
         self.client = EmsBigqueryClient(GCP_PROJECT_ID)
         self.storage_client = storage.Client()
 
+    def tearDown(self):
+        bucket = self.__get_test_bucket(self.TEST_BUCKET_NAME)
+        bucket.delete(True)
+
+
     def __create_test_table(self, table_name, dataset_id):
         table_schema = [SchemaField("int_data", "INT64"), SchemaField("str_data", "STRING")]
         table_reference = TableReference(dataset_id, table_name)
@@ -149,7 +156,7 @@ class ItEmsBigqueryClient(TestCase):
         expected_ids = [id1, id2]
         self.assertSetEqual(set(expected_ids), set(job_ids))
 
-    def test_relaunch_failed_jobs(self):
+    def test_relaunch_failed_query_jobs(self):
         job_prefix = "testprefix" + uuid.uuid4().hex
         id1 = self.client.run_async_query(self.DUMMY_QUERY, job_id_prefix=job_prefix)
         id2 = self.client.run_async_query(self.BAD_QUERY, job_id_prefix=job_prefix)
@@ -162,6 +169,28 @@ class ItEmsBigqueryClient(TestCase):
         min_creation_time = datetime.datetime.utcnow() - datetime.timedelta(minutes=1)
         job_ids = self.client.relaunch_failed_jobs(job_prefix, min_creation_time)
 
+        self.assertEqual(len(job_ids), 1)
+        self.assertRegex(job_ids[0], job_prefix + "-retry-1-.*")
+
+    def test_relaunch_failed_extract_jobs(self):
+        min_creation_time = datetime.datetime.utcnow()
+        job_prefix = "testprefix" + uuid.uuid4().hex
+        bucket = self.__get_test_bucket(self.TEST_BUCKET_NAME)
+        blob_name = f'exported_{int(min_creation_time.timestamp())}.csv'
+        good_bucket = f"gs://{self.TEST_BUCKET_NAME}/{blob_name}"
+        wrong_bucket = f"gs://ems_not_a_god_bucket_it_test/wrong_blob.vsct"
+        id1 = self.client.run_async_extract_job(job_prefix, self.__get_table_path(), [wrong_bucket], EmsExtractJobConfig())
+        id2 = self.client.run_async_extract_job(job_prefix, self.__get_table_path(), [good_bucket], EmsExtractJobConfig())
+        id3 = self.client.run_async_extract_job("unique_prefix", self.__get_table_path(), [wrong_bucket], EmsExtractJobConfig())
+
+        self.__wait_for_job_submitted(id1)
+        self.__wait_for_job_submitted(id2)
+        self.__wait_for_job_submitted(id3)
+
+        job_ids = self.client.relaunch_failed_jobs(job_prefix, min_creation_time)
+
+        bucket.delete_blob(blob_name)
+        self.assertEqual(len(job_ids), 1)
         self.assertRegex(job_ids[0], job_prefix + "-retry-1-.*")
 
     def test_get_job_list_returnsLoadJob(self):
@@ -182,7 +211,8 @@ class ItEmsBigqueryClient(TestCase):
         min_creation_time = datetime.datetime.utcnow()
         destination_uris = ["gs://some-non-existing-bucket-id/destination1"]
         table_path = self.__get_table_path()
-        unique_id = self.client.run_async_extract_job("extract_job_test", table_path, destination_uris)
+        unique_id = self.client.run_async_extract_job("extract_job_test", table_path, destination_uris,
+                                                      job_config=EmsExtractJobConfig())
         self.__wait_for_job_done(unique_id)
         jobs_iterator = self.client.get_jobs_with_prefix("extract_job_test", min_creation_time)
 
@@ -199,7 +229,7 @@ class ItEmsBigqueryClient(TestCase):
         self.client.run_sync_query(query)
         min_creation_time = datetime.datetime.utcnow()
 
-        bucket_name = GCP_PROJECT_ID + "-gcp-toolkit-it"
+        bucket_name = self.TEST_BUCKET_NAME
         bucket = self.__get_test_bucket(bucket_name)
         blob_name = f'exported_{int(min_creation_time.timestamp())}.csv'
 
@@ -217,7 +247,7 @@ class ItEmsBigqueryClient(TestCase):
         self.client.run_sync_query(query)
         min_creation_time = datetime.datetime.utcnow()
 
-        bucket_name = GCP_PROJECT_ID + "-gcp-toolkit-it"
+        bucket_name = self.TEST_BUCKET_NAME
         bucket = self.__get_test_bucket(bucket_name)
         blob_name = f'exported_{int(min_creation_time.timestamp())}.csv'
 
@@ -234,7 +264,10 @@ class ItEmsBigqueryClient(TestCase):
         table_path = self.__get_table_path()
         job_id_prefix = "extract_job_test"
         unique_id = self.client.run_async_extract_job(job_id_prefix, table_path, [f'gs://{bucket_name}/{blob_name}'],
-                                                      print_header)
+                                                      EmsExtractJobConfig(compression=Compression.NONE,
+                                                                          destination_format=DestinationFormat.CSV,
+                                                                          field_delimiter=",",
+                                                                          print_header=print_header))
         self.__wait_for_job_done(unique_id)
         jobs_iterator = self.client.get_jobs_with_prefix(job_id_prefix, min_creation_time)
         job: EmsExtractJob = next(j for j in jobs_iterator if j.job_id == unique_id)
@@ -252,7 +285,10 @@ class ItEmsBigqueryClient(TestCase):
         id_for_query_job = self.client.run_async_query(self.DUMMY_QUERY, job_id_prefix="it_job")
         id_for_load_job = self.client.run_async_load_job(job_id_prefix="it_job", config=load_config)
         id_for_extract_job = self.client.run_async_extract_job(job_id_prefix="it_job", table=self.__get_table_path(),
-                                                               destination_uris=destination_uris)
+                                                               destination_uris=destination_uris,
+                                                               job_config=EmsExtractJobConfig(compression=Compression.NONE, destination_format=DestinationFormat.CSV,
+                                                                          field_delimiter=",",
+                                                                          print_header=False))
 
         self.__wait_for_job_done(id_for_query_job)
         self.__wait_for_job_done(id_for_load_job)
@@ -400,4 +436,4 @@ class ItEmsBigqueryClient(TestCase):
 
     @staticmethod
     def __generate_test_name(context: str):
-        return "test_" + context + "_" + str(int(time.time()))
\ No newline at end of file
+        return "test_" + context + "_" + str(int(time.time()))
