@@ -5,13 +5,13 @@ from unittest.mock import patch, Mock
 
 from google.api_core.exceptions import GoogleAPIError
 from google.cloud import bigquery
-from google.cloud.bigquery import QueryJob, QueryPriority, LoadJob, LoadJobConfig, SchemaField, ExtractJob, \
-    QueryJobConfig
+from google.cloud.bigquery import QueryJob, QueryPriority, LoadJob, LoadJobConfig, SchemaField, ExtractJob
 from google.cloud.bigquery.schema import _parse_schema_resource
 from google.cloud.bigquery.table import Row, TableReference
 
 from bigquery.ems_api_error import EmsApiError
 from bigquery.ems_bigquery_client import EmsBigqueryClient, RetryLimitExceededError
+from bigquery.job.config.ems_extract_job_config import EmsExtractJobConfig, Compression, DestinationFormat
 from bigquery.job.config.ems_job_config import EmsCreateDisposition, EmsWriteDisposition
 from bigquery.job.config.ems_load_job_config import EmsLoadJobConfig
 from bigquery.job.config.ems_query_job_config import EmsQueryJobConfig
@@ -19,6 +19,8 @@ from bigquery.job.ems_job_state import EmsJobState
 from bigquery.job.ems_load_job import EmsLoadJob
 from bigquery.job.ems_query_job import EmsQueryJob
 
+DUMMY_TABLE_NAME = "my-project.mydataset.mytable"
+
 MIN_CREATION_TIME = datetime(1970, 4, 4)
 
 
@@ -132,13 +134,28 @@ class TestEmsBigqueryClient(TestCase):
         self.extract_job_mock = Mock(ExtractJob)
         self.extract_job_mock.job_id = expected_job_id
         self.client_mock.extract_table.return_value = self.extract_job_mock
+        ems_job_config = EmsExtractJobConfig(compression=Compression.GZIP,
+                                             destination_format=DestinationFormat.CSV,
+                                             field_delimiter="Deli mit R",
+                                             print_header=True)
 
-        ems_bigquery_client = EmsBigqueryClient(project_id)
+        ems_bigquery_client = EmsBigqueryClient(project_id, "Emelet")
         result_job_id = ems_bigquery_client.run_async_extract_job(job_id_prefix=job_prefix,
                                                                   table=table,
-                                                                  destination_uris=destination_uris)
+                                                                  destination_uris=destination_uris,
+                                                                  job_config=ems_job_config)
+        call_args_list = self.client_mock.extract_table.call_args_list
+        args = call_args_list[0][1]
 
-        self.assertEqual(result_job_id, expected_job_id)
+        assert args["location"] == "Emelet"
+        assert args["source"] == TableReference.from_string(table_id=table)
+        assert args["job_id_prefix"] == job_prefix
+        assert args["destination_uris"] == destination_uris
+        assert args["job_config"].compression == "GZIP"
+        assert args["job_config"].destination_format == "CSV"
+        assert args["job_config"].field_delimiter == "Deli mit R"
+        assert args["job_config"].print_header == True
+        assert result_job_id == expected_job_id
 
     def test_run_sync_query_submitsInteractiveQueryAndReturnsWithResultIterator(self, bigquery_module_patch: bigquery):
         ems_bigquery_client = self.__setup_client(bigquery_module_patch,
@@ -263,7 +280,8 @@ class TestEmsBigqueryClient(TestCase):
         self.assertEqual(result[0].query_config.destination_dataset, None)
         self.assertEqual(result[0].query_config.destination_table, None)
 
-    def test_get_job_list_returnsJobWithEmsQueryJobConfigWithDispositionsConvertedCorrectly(self, bigquery_module_patch: bigquery):
+    def test_get_job_list_returnsJobWithEmsQueryJobConfigWithDispositionsConvertedCorrectly(self,
+                                                                                            bigquery_module_patch: bigquery):
         bigquery_module_patch.Client.return_value = self.client_mock
         self.query_job_mock.job_id = "123"
         self.query_job_mock.query = "SELECT 1"
@@ -279,7 +297,6 @@ class TestEmsBigqueryClient(TestCase):
         self.assertEqual(result[0].query_config.write_disposition, EmsWriteDisposition.WRITE_APPEND)
         self.assertEqual(result[0].query_config.create_disposition, EmsCreateDisposition.CREATE_IF_NEEDED)
 
-
     def test_get_job_list_returnsJobWithEmsQueryJobConfigWithSetDestination(self, bigquery_module_patch: bigquery):
         bigquery_module_patch.Client.return_value = self.client_mock
         self.query_job_mock.job_id = "123"
@@ -306,10 +323,10 @@ class TestEmsBigqueryClient(TestCase):
 
         ems_bigquery_client = EmsBigqueryClient("some-project-id")
         min_creation_time = datetime.now()
-        query_jobs = ems_bigquery_client.get_jobs_with_prefix("prefixed", min_creation_time)
+        query_jobs = ems_bigquery_client.get_jobs_with_prefix("prefixed", min_creation_time, all_users=False)
 
         self.assertEqual(query_jobs, [])
-        self.client_mock.list_jobs.assert_called_with(all_users=True,
+        self.client_mock.list_jobs.assert_called_with(all_users=False,
                                                       max_results=20,
                                                       min_creation_time=min_creation_time,
                                                       max_creation_time=None)
@@ -344,29 +361,53 @@ class TestEmsBigqueryClient(TestCase):
         self.assertEqual("prefixed-retry-1-", arguments["job_id_prefix"])
         self.assertEqual(arguments["query"], "SIMPLE QUERY")
 
-    def test_relaunch_failed_jobs_startsQueryJobForAllTheJobs(self, bigquery_module_patch: bigquery):
+    def test_relaunch_failed_jobs_startsExtractJob(self, bigquery_module_patch: bigquery):
         bigquery_module_patch.Client.return_value = self.client_mock
-        first_job = self.__create_query_job_mock("prefixed-some-job-id", True)
-        second_job = self.__create_query_job_mock("prefixed-some-job-id", False)
-        self.client_mock.list_jobs.return_value = [first_job, second_job]
+        table = DUMMY_TABLE_NAME
+        job = self.__create_extract_job_mock("prefixed-some-job-id", table, True)
+        self.client_mock.list_jobs.return_value = [job]
+
+        ems_bigquery_client = EmsBigqueryClient("some-project-id", "valhalla")
+        ems_bigquery_client.relaunch_failed_jobs("prefixed", MIN_CREATION_TIME)
+
+        arguments = self.client_mock.extract_table.call_args_list[0][1]
+        self.assertEqual("prefixed-retry-1-", arguments["job_id_prefix"])
+        self.assertEqual(arguments["destination_uris"], job.destination_uris)
+        self.assertEqual(arguments["job_id_prefix"], "prefixed-retry-1-")
+        self.assertEqual(arguments["location"], "valhalla")
+        self.assertEqual(arguments["source"], TableReference.from_string(table))
+
+        self.assertEqual(arguments["job_config"].compression, job.compression)
+        self.assertEqual(arguments["job_config"].destination_format, job.destination_format)
+        self.assertEqual(arguments["job_config"].field_delimiter, job.field_delimiter)
+        self.assertEqual(arguments["job_config"].print_header, job.print_header)
+
+    def test_relaunch_failed_jobs_startsNewJobForAllFailedJobs(self, bigquery_module_patch: bigquery):
+        bigquery_module_patch.Client.return_value = self.client_mock
+        first_job = self.__create_query_job_mock("prefixed-query", True)
+        second_job = self.__create_query_job_mock("prefixed-done", False)
+        third_job = self.__create_extract_job_mock("prefixed-extract", DUMMY_TABLE_NAME, True)
+        self.client_mock.list_jobs.return_value = [first_job, second_job, third_job]
 
         ems_bigquery_client = EmsBigqueryClient("some-project-id")
         ems_bigquery_client.relaunch_failed_jobs("prefixed", MIN_CREATION_TIME)
 
         self.client_mock.query.assert_called_once()
-        first_call_args = self.client_mock.query.call_args_list[0][1]
-        self.assertEqual("prefixed-retry-1-", first_call_args["job_id_prefix"])
+        self.client_mock.extract_table.assert_called_once()
+        self.assertEqual("prefixed-retry-1-", self.client_mock.query.call_args_list[0][1]["job_id_prefix"])
+        self.assertEqual("prefixed-retry-1-", self.client_mock.extract_table.call_args_list[0][1]["job_id_prefix"])
 
-    def test_relaunch_failed_jobs_startsQueryJobWithIncreasedRetryIndex(self, bigquery_module_patch: bigquery):
+    def test_relaunch_failed_jobs_startsNewJobWithIncreasedRetryIndex(self, bigquery_module_patch: bigquery):
         bigquery_module_patch.Client.return_value = self.client_mock
-        first_job = self.__create_query_job_mock("prefixed-retry-1-some-job-id", True)
-        self.client_mock.list_jobs.return_value = [first_job]
+        query_job = self.__create_query_job_mock("prefixed-retry-1-some-random1", True)
+        extract_job = self.__create_extract_job_mock("prefixed-retry-1-some-random2", DUMMY_TABLE_NAME, True)
+        self.client_mock.list_jobs.return_value = [query_job, extract_job]
 
         ems_bigquery_client = EmsBigqueryClient("some-project-id")
         ems_bigquery_client.relaunch_failed_jobs("prefixed", MIN_CREATION_TIME)
 
-        arguments = self.client_mock.query.call_args_list[0][1]
-        self.assertEqual("prefixed-retry-2-", arguments["job_id_prefix"])
+        self.assertEqual("prefixed-retry-2-", self.client_mock.query.call_args_list[0][1]["job_id_prefix"])
+        self.assertEqual("prefixed-retry-2-", self.client_mock.extract_table.call_args_list[0][1]["job_id_prefix"])
 
     def test_relaunch_failed_jobs_canRetryMoreThanNineTimes(self, bigquery_module_patch: bigquery):
         bigquery_module_patch.Client.return_value = self.client_mock
@@ -425,6 +466,20 @@ class TestEmsBigqueryClient(TestCase):
         query_job_mock.error_result = error_result if has_error else None
         return query_job_mock
 
+    def __create_extract_job_mock(self, job_id: str, table: str, has_error: bool):
+        error_result = {'reason': 'someReason', 'location': 'query', 'message': 'error occurred'}
+        query_job_mock = Mock(ExtractJob)
+        query_job_mock.job_id = job_id
+        query_job_mock.destination_uris = ["uri1"]
+        query_job_mock.source = TableReference.from_string(table)
+        query_job_mock.compression = "GZIP"
+        query_job_mock.field_delimiter = ","
+        query_job_mock.print_header = True
+        query_job_mock.destination_format = "CSV"
+        query_job_mock.state = "DONE"
+        query_job_mock.error_result = error_result if has_error else None
+        return query_job_mock
+
     def __setup_client(self, bigquery_module_patch, return_value=None, location=None):
         project_id = "some-project-id"
         bigquery_module_patch.Client.return_value = self.client_mock
